@@ -36,10 +36,11 @@
 
 extern struct parser_state parser_state;
 
+int celex();
 int ceerror();                   /* dummy definition TODO: this is a douple */
 int ceparse();                   /* dummy definition. */
 int ceerror(char *s);
-int ce_parse(char *expression, int result[MP_SIZE]);
+int ce_parse(const char *expression, int result[MP_SIZE]);
 int ce_udf_parse(char *expression);
 
 void reset_ce_tokeniser();
